@@ -202,7 +202,7 @@ class Entri:
             "kata_turunan": [],
             "gabungan_kata": [],
             "peribahasa": [],
-            "kiasan": [],
+            "idiom": [],
         }
         terkait = entri.find_all("h4")
         for le in terkait:
@@ -276,7 +276,7 @@ class Entri:
             "kata_turunan": "\nKata Turunan",
             "gabungan_kata": "\nGabungan Kata",
             "peribahasa": f"\nPeribahasa (mengandung [{nama_murni}])",
-            "kiasan": f"\nKiasan (mengandung [{nama_murni}])",
+            "idiom": f"\nIdiom (mengandung [{nama_murni}])",
         }
         for key, head in header.items():
             if self.terkait[key]:
@@ -323,10 +323,10 @@ class Makna:
             self.submakna += f" ({nomor.text.strip()})"
 
     def _init_submakna(self, makna_label):
-        rujukan = makna_label.find("a")
         entris = makna_label.find("span", class_="entrisButton")
         if entris:
             entris.extract()
+        rujukan = makna_label.find("a")
         if rujukan and not rujukan.find("span", style="color:red"):
             self._init_rujukan(rujukan)
         elif makna_label.get("color") == "darkgreen":
@@ -348,6 +348,7 @@ class Makna:
             kelas = kelas.find_all("span")
         if makna_label.get("color") == "darkgreen":  # prakategorial
             kelas = [makna_label]
+        kelas = kelas or []
 
         self.kelas = []
         for k in kelas:
